Plone intranet

### Open Market Committee

The OMC holds eight regularly scheduled meetings during the year and other meetings as needed.

### Minifest

Nicht budgetierte einmalige Beiträge. Verein DAMP. Finanzielle Unterstützung des MinistrantInnen-...

### Managing Information

A range of guidance, tools and templates that can help you through the process of managing your i...

### Parliamentary papers guidance

'Parliamentary paper' is a term used to describe a document which is laid before Parliament. Most...

### Appraisal and selection masterclass

We offer a one-day appraisal and selection course for staff from government departments and publi...

### Supplying publications to MEPs

UK Members of the European Parliament (MEPs) are eligible to receive up to two copies of any qual...

### Digital continuity training

To reserve a place on one of these courses, please complete our online form.

### Schedules for keeping and disposing

Disposal scheduling is an important aspect of establishing and maintaining control of corporate i...

### Managing Risk

If not managed, information risks will have a significant impact on your ability to carry out you...

### Information Assurance and Cyber Security training

We are responsible for delivering a training and engagement programme for Senior Information Risk...

### Annual report and accounts

Government organisations have their own detailed project plans to produce the report and accounts...

### Exporting and transferring electronic data

Checklists for exporting and transferring electronic records data between systems

### Environmental Information regulations

The Freedom of Information Act gives rights of access to a wide range of information.